@@ -15,9 +15,8 @@ checkValidNodeName <- function(node) {
       stop("invalid node names: missing value NA not allowed")
     bad <- grep(EDGE_KEY_SEP, node, fixed=TRUE)
     if (length(bad))
-      stop("The following node names are invalid, they contain the ",
-           "edge separator ", sQuote(EDGE_KEY_SEP), "\n",
-           paste(node[bad], collapse=", "))
+      stop("node name(s) contain edge separator ",
+           sQuote(EDGE_KEY_SEP), ": ", pasteq(node[bad]))
     TRUE
 }
 
@@ -33,14 +32,13 @@ setMethod("isDirected", "graph",
 ## graphs or graphs within slots of objects will not be updated.
 updateFolder <- function(path="."){
     files <- dir(path, pattern="\\.rda$")
-    library(graph)
     for(f in files){
         env <- new.env()
         load(f, envir=env)
         objects <- ls(env)
         needSave <- FALSE
         for(i in objects){
-            if(is(get(i, env), "graph") && !graph:::isUpToDate(get(i, env))){
+            if(is(get(i, env), "graph") && !isUpToDate(get(i, env))){
                 assign(i, updateGraph(get(i, env)), envir=env)
                 cat("Updated graph object", i, "\n")
                 needSave <- TRUE
@@ -83,14 +81,13 @@ setMethod("edgemode", "graph", function(object)
           if(!isUpToDate(object)){
               ## first check in graphData then in edgemode slot
               if(!"graphData" %in% names(getObjectSlots(object))){
-                  .Deprecated(msg=EDGEMODE_DEFUNCT_MSG)
-                  em <- object@edgemode
+                  .Defunct(msg=EDGEMODE_DEFUNCT_MSG)
               }else{
                   em <- object@graphData$edgemode
                   if (is.null(em) && hasEdgemode(object))
                       em <- object@edgemode
                   if(is.null(em))
-                      stop("This 'graph' object is corrupted")
+                      stop("'graph' object is corrupted")
               }
           }else
           em <- object@graphData$edgemode
@@ -101,43 +98,44 @@ setMethod("edgemode", "graph", function(object)
 ## (FH 11/7/07) Changed this to update the object in case it is outdated
 ## (edgemode now lives as a list item in graphData) 
 setReplaceMethod("edgemode", c("graph", "character"),
-                 function(object, value) {
-                     if(length(value) != 1)
-                       stop("edgemode is the wrong length")
-                     if(!(value %in% c("directed", "undirected")) )
-                       stop(paste("supplied mode is", value,
-                                  "it must be either directed or undirected"))
-                     if(hasEdgemode(object)){
-                         warning("The edgemode slot is deprecated. ",
-                                 "This graph object has been updated to ",
-                                 "a new version.\n", call.=FALSE)
-                         object <- updateGraph(object)
-                     }
-                     object@graphData$edgemode <- value
-                     edgeRenderInfo(object) <- list(arrowhead=NULL, arrowtail=NULL)
-                     object
-                 })
+    function(object, value)
+{
+    if(length(value) != 1L)
+        stop("'edgemode' must be length 1")
+    if(!(value %in% c("directed", "undirected")) )
+        stop("'edgemode' must be 'directed' or 'undirected', was ",
+             sQuote(value))
+    if(hasEdgemode(object)){
+        warning("'edgemode' slot is deprecated; ",
+                "this graph object has been updated to ",
+                "a new version", call.=FALSE)
+        object <- updateGraph(object)
+    }
+    object@graphData$edgemode <- value
+    edgeRenderInfo(object) <- list(arrowhead=NULL, arrowtail=NULL)
+    object
+})
 
 
 ## Check if graph object is up to date
 isUpToDate <- function(object, error=FALSE)
 {
   if(!is(object, "graph"))
-    stop("Object must inherit from class 'graph'")
+    stop("'object' must inherit from class 'graph'")
   availSlots <- getObjectSlots(object)
   availSlotNames <- names(availSlots)
   definedSlotNames <- slotNames(object)
   valid <- setequal(availSlotNames, definedSlotNames) &&
                     length(object@graphData$edgemode)
   if(error && !valid)
-    .Deprecated(msg=EDGEMODE_DEFUNCT_MSG)
+    .Defunct(msg=EDGEMODE_DEFUNCT_MSG)
   return(valid)
 }
 
 hasEdgemode <- function(object)
 {
    if(!is(object, "graph"))
-     stop("Object must inherit from class 'graph'")
+     stop("'object' must inherit from class 'graph'")
    sn <- names(getObjectSlots(object))
    return("edgemode" %in% sn)
 }
@@ -149,7 +147,7 @@ setMethod("updateGraph", "graph", function(object)
           availSlots <- getObjectSlots(object)
           availSlotNames <- names(availSlots)
           definedSlotNames <- slotNames(object)
-          if(graph:::isUpToDate(object)){
+          if(isUpToDate(object)){
               message("This graph object seems to be up to date")
               newObject <- object
           }else{
@@ -157,7 +155,7 @@ setMethod("updateGraph", "graph", function(object)
               missingSlots <- setdiff(definedSlotNames, availSlotNames)
               if("graphData" %in% missingSlots &&
                  !"edgemode" %in% availSlotNames)
-                stop("Object is corrupted, don't know how to update.")
+                stop("'object' is corrupted, don't know how to update.")
               newObject <- new(class(object))
               for(s in commonSlots)
                   slot(newObject, s) <- availSlots[[s]]
@@ -190,37 +188,35 @@ setMethod("numEdges", signature(object="graph"),
 setMethod("isAdjacent",signature(object="graph", from="character",
                                  to="character"),
           function(object, from, to) {
-              eSpec <- graph:::.normalizeEdges(from, to)
+              eSpec <- .normalizeEdges(from, to)
               from <- eSpec$from
               to <- eSpec$to
               fromIdx <- match(from, nodes(object), nomatch=0)
               toIdx <- match(to, nodes(object), nomatch=0)
               if (any(fromIdx == 0))
-                stop("Unknown nodes in from: ",
-                     paste(from[fromIdx == 0], collapse=", "))
+                stop("unknown nodes in 'from': ",
+                     pasteq(from[fromIdx == 0]))
               if (any(toIdx == 0))
-                stop("Unknown nodes in to: ",
-                     paste(to[toIdx == 0], collapse=", "))
+                stop("unknown nodes in 'to': ",
+                     pasteq(to[toIdx == 0]))
               fromEdges <- edges(object)[from]
-              .Call("graph_is_adjacent", fromEdges, to,
-                    PACKAGE="BioC_graph")
+              .Call(graph_is_adjacent, fromEdges, to)
           })
 
 
-  ##handle directed graphs by a list inDegree and outDegree
-  setMethod("degree", signature(object="graph", Nodes="missing"),
-      function(object)  {
-          degree(object, Nodes=nodes(object))
-     })
-
-  setMethod("degree", "graph",  function(object, Nodes) {
+setMethod("degree", "graph",  function(object, Nodes) {
        nl <- edges(object)
-       nls <- nl[Nodes]
+       if (missing(Nodes))
+           Nodes <- nodes(object)
+       nls <- nl[Nodes] 
 
        deg <- listLen(nls)
        names(deg) <- Nodes
-       if (!isDirected(object))
-           return(deg)
+
+       if (!isDirected(object)) {
+           nself <- sapply(Nodes, function(n) sum(n == nl[[n]]))
+           return(deg + nself)
+           } 
        else {
            b1 <- unlist(nl)
            b2 <- table(b1)
@@ -231,6 +227,10 @@ setMethod("isAdjacent",signature(object="graph", from="character",
        }
   })
 
+
+
+
+
 setMethod("leaves", "graph",
           function(object, degree.dir) {
               deg <- degree(object)
@@ -278,7 +278,7 @@ setMethod("leaves", "graph",
 
        rval <- vector("list", length=nIndex)
        names(rval) <- nNames[whN]
-       for( i in 1:nIndex) {
+       for( i in seq_len(nIndex)) {
            marked<-rep(0, nN)
            distv <- rep(0, nN)
            names(distv) <- nNames
@@ -313,10 +313,9 @@ setMethod("edgeWeights", signature(object="graph", index="character"),
           {
               ## Check extra args
               if (!is.character(attr) || length(attr) != 1)
-                stop(sQuote("attr"),
-                     " must be a character vector of length one.")
+                stop("'attr' must be character(1)")
               if (!is.null(type.checker) && !is.function(type.checker))
-                stop(sQuote("type.checker"), " must be a function or NULL.")
+                stop("'type.checker' be a function or NULL")
               
               if (! attr %in% names(edgeDataDefaults(object))) {
                   ## No existing 'weight' edge attr, uses default
@@ -332,8 +331,7 @@ setMethod("edgeWeights", signature(object="graph", index="character"),
               names(ew) <- unlist(gEdges, use.names=FALSE)
               ew <- unlist(ew)
               if (!is.null(type.checker) && !isTRUE(type.checker(ew)))
-                stop("invalid type of edge weight.\n",
-                     "type.checker(ew) not TRUE\n",
+                stop("edge weight type.checker(ew) not TRUE\n",
                      "typeof(ew): ", typeof(ew))
 
 ##               for (el in ew) {
@@ -387,7 +385,7 @@ setMethod("DFS", c("graph", "character", "ANY"), function(object, node,
     names(marked) <- nNames
     m1 <- match(node, nNames)
     if( is.na(m1) )
-        stop(paste("node:", node, "is not in the graph"))
+        stop("node not in graph: ", sQuote(node))
 
     ##this could be expensive
     if (checkConn) {
@@ -423,8 +421,8 @@ setMethod("intersection2", c("graph", "graph"), function(x,y) {
         else
            edgeM <- 1
 
-        .Call("graphIntersection", nodes(x), nodes(y),
-              edges(x), edges(y), edgeM, PACKAGE="BioC_graph")
+        .Call(graph_intersection, nodes(x), nodes(y), edges(x),
+              edges(y), edgeM)
 
 })
 
@@ -435,7 +433,7 @@ setMethod("intersection2", c("graph", "graph"), function(x,y) {
        yN <- nodes(y)
        bN <- intersect(xN, yN)
        if( length(bN) == 0 )
-           return(new("graphNEL", nodes=character(0),
+           return(graphNEL(nodes=character(0),
                       edgeL=vector("list", 0), edgemode=edgemode(x)))
        ##lb <- length(bN)
        ##if(lb != length(xN) || lb != length(yN))
@@ -447,13 +445,13 @@ setMethod("intersection2", c("graph", "graph"), function(x,y) {
        yE = lapply(yE, function(x) {
            x[x %in% bN]})
        rval <- vector("list", length=length(xE))
-       for(i in 1:length(xE) ) {
+       for(i in seq_along(xE) ) {
            ans <- intersect(xE[[i]], yE[[i]])
            rval[[i]] <- list(edges=match(ans, bN),
                                  weights=rep(1, length(ans)))
        }
        names(rval) <- bN
-       new("graphNEL", nodes=bN, edgeL=rval, edgemode=edgemode(x))
+       graphNEL(nodes=bN, edgeL=rval, edgemode=edgemode(x))
    })
 
 setMethod("join", c("graph", "graph"), function(x, y) {
@@ -461,7 +459,7 @@ setMethod("join", c("graph", "graph"), function(x, y) {
     if(ex == ey)
         outmode <- ex
     else
-        stop("cannot handle different edgemodes, yet")
+        stop("cannot handle different edgemodes")
 
     nX <- nodes(x)
     numXnodes <- length(nX)
@@ -478,16 +476,16 @@ setMethod("join", c("graph", "graph"), function(x, y) {
     ## as the node #s have all changed.
     if (length(eLY) > 0) {
         eLYnames <- names(eLY)
-        for (i in 1:length(eLY)) {
+        for (i in seq_along(eLY)) {
             newEntry <- eLY[i]
             ## !! first need to adjust the targets on the edges
             newEdges <- newEntry[[1]]$edges
             if (length(newEdges) > 0) {
-                for (j in 1:length(newEdges)) {
+                for (j in seq_along(newEdges)) {
                     curTo <- nY[newEdges[j]]
                     newTo <- match(curTo,newNodes)
                     if (is.na(newTo))
-                        stop("Error reassigning duplicated nodes")
+                        stop("error reassigning duplicated nodes")
                     newEdges[j] <- newTo
                 }
             }
@@ -501,7 +499,7 @@ setMethod("join", c("graph", "graph"), function(x, y) {
             else if (eLYnames[i] %in% nX) {
                 entry <- which(names(newEdgeL) == eLYnames[i])
                 if (length(entry) > 1)
-                    stop("Duplicated node names in original graph")
+                    stop("duplicated node names in original graph")
                 curEntry <- newEdgeL[[entry]]
                 curEntry$edges <- c(curEntry$edges, newEntry[[1]]$edges)
                 curEntry$weights <- c(curEntry$weights,
@@ -524,7 +522,7 @@ setMethod("join", c("graph", "graph"), function(x, y) {
     ## Some graphs have edgeL's that are missing the original
     ## node from the edgeL.  When we collated the edgeL above,
     ## those nodes will be missing - so need to make sure that
-    ## all nodes are present, as the new("graphNEL") call below
+    ## all nodes are present, as the graphNEL() call below
     ## will check to make sure that length(nodes) == length(edgeL)
     for (missNode in newNodes[! newNodes %in% names(newEdgeL)]) {
         newEdgeL[[length(newEdgeL) + 1]] <- list(edges=numeric(),
@@ -532,17 +530,17 @@ setMethod("join", c("graph", "graph"), function(x, y) {
         names(newEdgeL)[length(newEdgeL)] <- missNode
     }
 
-    new("graphNEL", nodes=newNodes, edgeL=newEdgeL, edgemode=ex)
+    graphNEL(nodes=newNodes, edgeL=newEdgeL, edgemode=ex)
 })
 
 
 
-setMethod("union", c("graph", "graph"), function(x, y) {
+setMethod("union", c("graph", "graph"), function(x, y, ...) {
     ex <- edgemode(x); ey <- edgemode(y);
     if( ex == ey )
         outmode <- ex
     else
-        stop("cannot handle different edgemodes, yet")
+        stop("cannot handle different edgemodes")
 
     xN <- sort(nodes(x))
     yN <- sort(nodes(y))
@@ -562,14 +560,14 @@ setMethod("union", c("graph", "graph"), function(x, y) {
                 list(edges=numeric(0), weights=numeric(0))
     }
     names(rval) <- xN
-    new("graphNEL", nodes=xN, edgeL=rval, edgemode=outmode)
+    graphNEL(nodes=xN, edgeL=rval, edgemode=outmode)
 })
 
 
 
 setMethod("complement", c("graph"), function(x) {
     if( edgemode(x) != "undirected" )
-        stop(paste("can't handle edgemode:", edgemode(x), "yet"))
+        stop("'edgemode' not supported: ", sQuote(edgemode(x)))
 
     xN <- nodes(x)
     xE <- edges(x)
@@ -584,7 +582,7 @@ setMethod("complement", c("graph"), function(x) {
         else
             rval[[i]] <- list(edges=numeric(0), weights=numeric(0))
     }
-    new("graphNEL", nodes=xN, edgeL=rval, edgemode=edgemode(x))
+    graphNEL(nodes=xN, edgeL=rval, edgemode=edgemode(x))
 })
 
 ##connected components
@@ -618,7 +616,7 @@ setMethod("connComp", "graph", function(object) {
     nmR <- NL[nused]
     nc <- length(rval)
     rL <- vector("list", length=nc)
-    for(i in 1:nc) rL[[i]]<-c(nmR[[i]], names(rval[[i]]))
+    for(i in seq_len(nc)) rL[[i]]<-c(nmR[[i]], names(rval[[i]]))
     return(rL)
 })
 
@@ -644,14 +642,14 @@ setMethod("show", signature("graph"),
     gN <- nodes(graph)
     wF <- match(from, gN)
     if( is.na(wF) )
-        stop(paste(from, "is not a node"))
+        stop("not a node: ", sQuote(from))
     wT <- match(to, gN)
     if( is.na(wT) )
-        stop(paste(to, "is not a node"))
+        stop("not a node: ", sQuote(to))
     eL <- graph@edgeL[[from]]
     mt <- match(wT, eL$edges)
     if(is.na(mt) )
-        stop(paste("no edge from", from, "to", to))
+        stop("no edge from ", sQuote(from), " to ", sQuote(to))
     eL$weights[mt]
 }
 
@@ -660,23 +658,23 @@ setMethod("show", signature("graph"),
 sparseM2Graph <- function(sM, nodeNames, edgemode=c("directed", "undirected"))
 {
     ## FIXME: this needs to become a method
-    require("SparseM") || stop("need SparseM for this operation")
+    qrequire("SparseM")
     edgemode <- match.arg(edgemode)
     nN <- dim(sM)[1]
     if( nN != dim(sM)[2] )
-        stop("only square matrices can be transformed, now")
+        stop("only square matrices can be transformed")
     if( length(nodeNames) != nN )
         stop("wrong number of node names supplied")
     if( !is.character(nodeNames) )
         stop("wrong type of node names supplied")
     dd <- diff(sM@ia)
-    e1 <- rep(1:nN, dd)
+    e1 <- rep(seq_len(nN), dd)
     eL <- split(sM@ja, e1)
     eW <- split(sM@ra, e1)
 
     edL <- vector("list", length=nN)
-    names(edL) <- 1:nN
-    for(i in as.character(1:nN) ){
+    names(edL) <- seq_len(nN)
+    for(i in as.character(seq_len(nN)) ){
         ##need this because otherwise partial matching is done
         if( i %in% names(eL) )
             edL[[i]] <- list(edges=eL[[i]], weights=eW[[i]])
@@ -684,7 +682,7 @@ sparseM2Graph <- function(sM, nodeNames, edgemode=c("directed", "undirected"))
           edL[[i]] <- list(edges=numeric(0))
     }
     names(edL) <- nodeNames
-    new("graphNEL", nodes=nodeNames, edgeL=edL, edgemode=edgemode)
+    graphNEL(nodes=nodeNames, edgeL=edL, edgemode=edgemode)
 }
 
 ##translate a graph to a SparseMatrix:
@@ -693,7 +691,7 @@ sparseM2Graph <- function(sM, nodeNames, edgemode=c("directed", "undirected"))
 ##ia the row offsets (
 graph2SparseM <- function(g, useweights=FALSE) {
     ## FIXME: this needs to become a method
-    require("SparseM") || stop("need SparseM for this operation")
+    qrequire("SparseM")
     if (! is(g, "graphNEL"))
        stop("coercion only works for graphNEL class")
     nr = nc = numNodes(g)
@@ -724,7 +722,7 @@ setMethod("edgeNames",
     from <- match(names(to), nodes(object))
 
     if(any(is.na(unlist(to)))||any(is.na(from)))
-      stop("Edge names do not match node names.")
+      stop("edge names do not match node names")
 
     ## from-to matrix
     ft <- matrix(c(rep(from, listLen(to)), to=unlist(to)), ncol=2)
@@ -758,13 +756,13 @@ setMethod("clusteringCoefficient",
   from <- match(names(to), nodes(object))
 
   if(any(is.na(unlist(to)))||any(is.na(from)))
-    stop("Edge names do not match node names.")
+    stop("edge names do not match node names")
 
   if(!selfLoops) {
     ufrom <- rep(from, listLen(to))
     uto   <- unlist(to)
     if(any(ufrom==uto))
-      stop("Graph must not contain self-loops.")
+      stop("graph must not contain self-loops")
     totEdges <- function(i) i*(i-1)
   } else {
     totEdges <- function(i) i*i
@@ -813,8 +811,7 @@ setReplaceMethod("nodeDataDefaults", signature(self="graph", attr="character",
 .verifyNodes <- function(n, nodes) {
     unknownNodes <- n[! n %in% nodes]
     if (length(unknownNodes) > 0)
-      stop("Unknown nodes: ",
-           paste(unknownNodes, collapse=", "))
+      stop("unknown nodes: ", pasteq(unknownNodes))
     TRUE
 }
 
@@ -822,7 +819,7 @@ setReplaceMethod("nodeDataDefaults", signature(self="graph", attr="character",
 setMethod("nodeData",
           signature(self="graph", n="character", attr="character"),
           function(self, n, attr) {
-              graph:::.verifyNodes(n, nodes(self))
+              .verifyNodes(n, nodes(self))
               attrDataItem(self@nodeData, x=n, attr=attr)
           })
 
@@ -831,7 +828,7 @@ setReplaceMethod("nodeData",
                  signature(self="graph", n="character", attr="character",
                            value="ANY"),
                  function(self, n, attr, value) {
-                     graph:::.verifyNodes(n, nodes(self))
+                     .verifyNodes(n, nodes(self))
                      attrDataItem(self@nodeData, x=n, attr=attr) <- value
                      self
           })
@@ -840,7 +837,7 @@ setReplaceMethod("nodeData",
 setMethod("nodeData",
           signature(self="graph", n="character", attr="missing"),
           function(self, n, attr) {
-              graph:::.verifyNodes(n, nodes(self))
+              .verifyNodes(n, nodes(self))
               attrDataItem(self@nodeData, x=n)
           })
 
@@ -908,11 +905,11 @@ setReplaceMethod("edgeDataDefaults", signature(self="graph", attr="character",
     lenTo <- length(to)
     if (lenFr > lenTo) {
         if (lenTo != 1)
-          stop("'to' must be length 1 or ", lenFr, " for this call.")
+          stop("'to' must be length 1 or ", lenFr)
         to <- rep(to, lenFr)
     } else if (lenFr < lenTo) {
         if (lenFr != 1)
-          stop("'from' must be length 1 or ", lenTo, " for this call.")
+          stop("'from' must be length 1 or ", lenTo)
         from <- rep(from, lenTo)
     }
     list(from=from, to=to)
@@ -927,7 +924,7 @@ setReplaceMethod("edgeDataDefaults", signature(self="graph", attr="character",
         badFr <- from[!adjList]
         badTo <- to[!adjList]
         res <- paste(badFr, badTo, sep=EDGE_KEY_SEP, collapse=", ")
-        stop("Edges not found: ", res)
+        stop("edges not found: ", sQuote(res))
     }
     TRUE
 }
@@ -940,11 +937,11 @@ setReplaceMethod("edgeDataDefaults", signature(self="graph", attr="character",
 
 
 .getEdgeKeys <- function(graph, from, to) {
-    eSpec <- graph:::.normalizeEdges(from, to)
+    eSpec <- .normalizeEdges(from, to)
     from <- eSpec$from
     to <- eSpec$to
-    graph:::.verifyEdges(graph, from, to)
-    edgeKeys <- graph:::.makeEdgeKeys(from, to)
+    .verifyEdges(graph, from, to)
+    edgeKeys <- .makeEdgeKeys(from, to)
     edgeKeys
 }
 
@@ -952,7 +949,7 @@ setReplaceMethod("edgeDataDefaults", signature(self="graph", attr="character",
 setMethod("edgeData", signature(self="graph", from="character", to="character",
                                 attr="character"),
           function(self, from, to, attr) {
-              edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+              edgeKeys <- .getEdgeKeys(self, from, to)
               attrDataItem(self@edgeData, x=edgeKeys, attr=attr)
           })
 
@@ -960,14 +957,14 @@ setMethod("edgeData", signature(self="graph", from="character", to="character",
 setMethod("edgeData", signature(self="graph", from="character", to="missing",
                                 attr="character"),
           function(self, from, to, attr) {
-              graph:::.verifyNodes(from, nodes(self))
+              .verifyNodes(from, nodes(self))
               gEdges <- edges(self)[from]
               lens <- sapply(gEdges, length)
               fEdges <- rep(from, lens)
               if (!length(fEdges))
                 return(list())
               tEdges <- unlist(gEdges)
-              edgeKeys <- graph:::.getEdgeKeys(self, fEdges, tEdges)
+              edgeKeys <- .getEdgeKeys(self, fEdges, tEdges)
               attrDataItem(self@edgeData, x=edgeKeys, attr=attr)
           })
 
@@ -980,7 +977,7 @@ setMethod("edgeData", signature(self="graph", from="missing", to="character",
               to <- rep(to, sapply(inE, length))
               from <- unlist(inE)
               ## from <- names(eDat)[sapply(eDat, function(x) to %in% x)]
-              edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+              edgeKeys <- .getEdgeKeys(self, from, to)
               attrDataItem(self@edgeData, x=edgeKeys, attr=attr)
           })
 
@@ -989,10 +986,10 @@ setReplaceMethod("edgeData",
                  signature(self="graph", from="character", to="character",
                            attr="character", value="ANY"),
                  function(self, from, to, attr, value) {
-                     edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+                     edgeKeys <- .getEdgeKeys(self, from, to)
                      attrDataItem(self@edgeData, x=edgeKeys, attr=attr) <- value
                      if (!isDirected(self)) {
-                         edgeKeys <- graph:::.getEdgeKeys(self, to, from)
+                         edgeKeys <- .getEdgeKeys(self, to, from)
                          attrDataItem(self@edgeData, x=edgeKeys,
                                       attr=attr) <- value
                      }
@@ -1004,18 +1001,18 @@ setReplaceMethod("edgeData",
                  signature(self="graph", from="character", to="missing",
                            attr="character", value="ANY"),
                  function(self, from, to, attr, value) {
-                     graph:::.verifyNodes(from, nodes(self))
+                     .verifyNodes(from, nodes(self))
                      gEdges <- edges(self)[from]
                      lens <- sapply(gEdges, length)
                      if (any(lens == 0))
-                       warning("No edges from nodes: ",
-                               paste(from[lens == 0], collapse=", "))
+                       warning("no edges from nodes: ",
+                               pasteq(from[lens == 0]))
                      fEdges <- rep(from, lens)
                      tEdges <- unlist(edges(self)[from])
-                     edgeKeys <- graph:::.getEdgeKeys(self, fEdges, tEdges)
+                     edgeKeys <- .getEdgeKeys(self, fEdges, tEdges)
                      attrDataItem(self@edgeData, x=edgeKeys, attr=attr) <- value
                      if (!isDirected(self)) {
-                         edgeKeys <- graph:::.getEdgeKeys(self, tEdges, fEdges)
+                         edgeKeys <- .getEdgeKeys(self, tEdges, fEdges)
                          attrDataItem(self@edgeData, x=edgeKeys,
                                       attr=attr) <- value
                      }
@@ -1029,10 +1026,10 @@ setReplaceMethod("edgeData",
                  function(self, from, to, attr, value) {
                      eDat <- edges(self)
                      from <- names(eDat)[sapply(eDat, function(x) to[1] %in% x)]
-                     edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+                     edgeKeys <- .getEdgeKeys(self, from, to)
                      attrDataItem(self@edgeData, x=edgeKeys, attr=attr) <- value
                      if (!isDirected(self)) {
-                         edgeKeys <- graph:::.getEdgeKeys(self, to, from)
+                         edgeKeys <- .getEdgeKeys(self, to, from)
                          attrDataItem(self@edgeData, x=edgeKeys,
                                       attr=attr) <- value
                      }
@@ -1055,10 +1052,10 @@ setReplaceMethod("edgeData",
 setMethod("edgeData", signature(self="graph", from="missing", to="missing",
                                 attr="character"),
           function(self, from, to, attr) {
-              eSpec <- graph:::.getAllEdges(self)
+              eSpec <- .getAllEdges(self)
               from <- eSpec$from
               to <- eSpec$to
-              edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+              edgeKeys <- .getEdgeKeys(self, from, to)
               attrDataItem(self@edgeData, x=edgeKeys, attr=attr)
           })
 
@@ -1066,7 +1063,7 @@ setMethod("edgeData", signature(self="graph", from="missing", to="missing",
 setMethod("edgeData", signature(self="graph", from="character", to="character",
                                 attr="missing"),
           function(self, from, to, attr) {
-              edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+              edgeKeys <- .getEdgeKeys(self, from, to)
               attrDataItem(self@edgeData, x=edgeKeys)
           })
 
@@ -1074,10 +1071,10 @@ setMethod("edgeData", signature(self="graph", from="character", to="character",
 setMethod("edgeData", signature(self="graph", from="missing", to="missing",
                                 attr="missing"),
           function(self, from, to, attr) {
-              eSpec <- graph:::.getAllEdges(self)
+              eSpec <- .getAllEdges(self)
               from <- eSpec$from
               to <- eSpec$to
-              edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+              edgeKeys <- .getEdgeKeys(self, from, to)
               attrDataItem(self@edgeData, x=edgeKeys)
           })
 
@@ -1085,29 +1082,18 @@ setMethod("edgeData", signature(self="graph", from="missing", to="missing",
 setMethod("edgeL", "graph",
 	  function(graph, index) callGeneric(as(graph, "graphNEL")))
 
-## This is a placeholder; if it's missing, i.e., currently,
-## and 'Rgraphviz' is not loaded, users get bad error messages.
-## Unfortunately, it doesn't work -- to MM, this seems like a bug in R
-if(FALSE)
-setMethod("plot", "graph",
-	  function(x, y, ...) {
-	      if(require("Rgraphviz")) {
-		  ## Remove 'myself' :
-		  removeMethod("plot", "graph",
-                               where = as.environment("package:graph"))
-		  message("now that the 'Rgraphviz' package is loaded, try again...")
-	      }
-	      else stop("'Rgraphviz' package is required for plot(<graph>)")
-	      ## else, try again *after* loading 'Rgraphviz':
-	      ## gives infinite recursion:	 callGeneric()
-	      ## gives infinite recursion:	 plot(x,y, ...)
-	      ## dispatches to S3 plot.default:	 callNextMethod()
-	  })
-
+setMethod("plot", c("graph", "ANY"),
+    function(x, y, ...)
+{
+    qrequire("Rgraphviz")
+    method <- getMethod("plot", c("graph", "ANY"),
+                        getNamespace("Rgraphviz"))
+    method(x, y, ...)
+})
 
 clearEdgeData <- function(self, from, to) {
     ##FIXME: make me a method
-    edgeKeys <- graph:::.getEdgeKeys(self, from, to)
+    edgeKeys <- .getEdgeKeys(self, from, to)
     removeAttrDataItem(self@edgeData, x=edgeKeys) <- NULL
     self
 }
