@@ -1,14 +1,13 @@
 #include <Rinternals.h>
 #include <Rdefines.h>
 #include <Rmath.h>
-#include <R_ext/RConverters.h>
 #include <R_ext/Rdynload.h>
 
 SEXP R_scalarString(const char *);
 SEXP intersectStrings(SEXP, SEXP);
-SEXP graphIntersection(SEXP, SEXP, SEXP, SEXP, SEXP);
+SEXP graph_intersection(SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP checkEdgeList(SEXP, SEXP);
-SEXP listLen(SEXP);
+SEXP graph_listLen(SEXP);
 SEXP graph_attrData_lookup(SEXP attrObj, SEXP keys, SEXP attr);
 SEXP graph_sublist_assign(SEXP x, SEXP subs, SEXP sublist, SEXP values);
 SEXP graph_is_adjacent(SEXP fromEdges, SEXP to);
@@ -34,8 +33,8 @@ SEXP graph_bitarray_getEdgeAttrOrder(SEXP , SEXP , SEXP );
 
 static const R_CallMethodDef R_CallDef[] = {
     {"intersectStrings", (DL_FUNC)&intersectStrings, 2},
-    {"graphIntersection", (DL_FUNC)&graphIntersection, 5},
-    {"listLen", (DL_FUNC)&listLen, 1},
+    {"graph_intersection", (DL_FUNC)&graph_intersection, 5},
+    {"graph_listLen", (DL_FUNC)&graph_listLen, 1},
     {"graph_attrData_lookup", (DL_FUNC)&graph_attrData_lookup, 3},
     {"graph_sublist_assign", (DL_FUNC)&graph_sublist_assign, 4},
     {"graph_is_adjacent", (DL_FUNC)&graph_is_adjacent, 2},
@@ -101,8 +100,8 @@ SEXP intersectStrings(SEXP x, SEXP y) {
 }
 
 
-SEXP graphIntersection(SEXP xN, SEXP yN, SEXP xE, SEXP yE,
-		       SEXP edgeMode) {
+SEXP graph_intersection(SEXP xN, SEXP yN, SEXP xE, SEXP yE,
+                        SEXP edgeMode) {
     /* edgeMode == 0 implies "undirected" */
     SEXP bN, newXE, newYE;
     SEXP klass, outGraph;
@@ -121,7 +120,7 @@ SEXP graphIntersection(SEXP xN, SEXP yN, SEXP xE, SEXP yE,
     if (length(bN) == 0) {
 	SET_SLOT(outGraph, Rf_install("nodes"), allocVector(STRSXP, 0));
 	SET_SLOT(outGraph, Rf_install("edgeL"), allocVector(VECSXP, 0));
-	UNPROTECT(1);
+	UNPROTECT(2);
 	return(outGraph);
     }
     PROTECT(newXE = checkEdgeList(xE, bN));
@@ -206,7 +205,7 @@ SEXP checkEdgeList(SEXP eL, SEXP bN) {
 }
 
 /* Taken from Biobase to avoid depending on it */
-SEXP listLen(SEXP x)
+SEXP graph_listLen(SEXP x)
 {
   SEXP ans;
   int i;
@@ -706,10 +705,10 @@ SEXP graph_bitarray_edgeSetToMatrix(SEXP nodes, SEXP bits,
             linIndx++;
         }
     }
-    SET_NAMED(_dim, 2);
+    MARK_NOT_MUTABLE(_dim);
     setAttrib(ans, R_DimSymbol, _dim);
     PROTECT(dnms = allocVector(VECSXP, 2));
-    /* Arguments to .Call have NAMED(x) == 2, so we can
+    /* Arguments to .Call are marked as not mutable, so we can
        reuse here.
      */
     SET_VECTOR_ELT(dnms, 0, nodes);
@@ -890,7 +889,7 @@ SEXP graph_bitarray_getEdgeAttrOrder(SEXP _bits, SEXP _from, SEXP _to) {
     PROTECT(newLeftPos = allocVector(INTSXP, len));
 
     setCount =1;
-    for(j =0; j < dim ; j ++) {
+    for(j =0; j < dim; j ++) {
         for(i =0; i < dim; i++){
             indx =  COORD_TO_INDEX(i, j , dim);
             byteIndex = indx / 8;
@@ -906,8 +905,10 @@ SEXP graph_bitarray_getEdgeAttrOrder(SEXP _bits, SEXP _from, SEXP _to) {
                 }
             }
             if(intIndx == indx) {
-               INTEGER(newRightPos)[nindx] =  nindx + 1;
-               INTEGER(newLeftPos)[nindx] = setCount  ;
+               if (nindx < len) { /* guard nindex == 0, len == 0 */
+                 INTEGER(newRightPos)[nindx] =  nindx + 1;
+                 INTEGER(newLeftPos)[nindx] = setCount  ;
+               }
                nindx++;
                if(attrIndx < len-1){
                    attrIndx++; 
